@@ -1,6 +1,6 @@
 PRAGMA foreign_keys=OFF;
 BEGIN TRANSACTION;
-CREATE TABLE users (
+CREATE TABLE IF NOT EXISTS users (
     uuid VARCHAR(36) NOT NULL,
     nickname VARCHAR(200) NOT NULL,
     pkey_hash VARCHAR(40) NOT NULL,
